'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _del = require('del');

var _del2 = _interopRequireDefault(_del);

var _jsonfile = require('jsonfile');

var _jsonfile2 = _interopRequireDefault(_jsonfile);

var _replaceInFile = require('replace-in-file');

var _replaceInFile2 = _interopRequireDefault(_replaceInFile);

var _messages = require('./messages');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var cleanFiles = function cleanFiles(answers) {

  var pathsToNuke = ['.git', 'docs', '.codeclimate.yml', '.coveralls.yml', '.travis.yml', 'appveyor.yml', 'upgrade_deps.sh', 'LICENSE', 'README.md', 'packages', 'TODO', 'lerna.json', 'add', 'yarn.lock'];

  if (!answers.includeTests) {

    pathsToNuke.push('test/server');
  }

  return new Promise(function (resolve, reject) {

    (0, _del2.default)(pathsToNuke.map(function (p) {
      return answers.targetPath + '/' + p;
    })).then(function () {
      resolve(answers);
    }).catch(function (err) {
      reject(err);
    });
  });
};

var tweakPackageJson = function tweakPackageJson(answers) {
  return new Promise(function (resolve, reject) {

    var packageFilePath = answers.targetPath + '/package.json';
    var appName = answers.appName;
    var basisText = 'basis';
    var babelNodeText = 'babel-node';
    var packageSpecsText = 'packages/**/*Spec.js ';

    _jsonfile2.default.readFile(packageFilePath, function (readError, packageJson) {

      if (readError) {
        reject(readError);
      }

      var outputPackageJson = Object.assign(packageJson);
      delete outputPackageJson.description;
      delete outputPackageJson.repository;
      delete outputPackageJson.keywords;
      delete outputPackageJson.author;
      delete outputPackageJson.bugs;
      delete outputPackageJson.homepage;
      delete outputPackageJson.scripts['publish-coverage'];
      delete outputPackageJson.scripts['link:packages'];
      delete outputPackageJson.scripts['unlink:packages'];
      delete outputPackageJson.scripts['publish:packages'];
      delete outputPackageJson.private;
      delete outputPackageJson.workspaces;
      outputPackageJson.name = answers.appName;
      outputPackageJson.scripts.start = outputPackageJson.scripts.start.replace(basisText, appName).replace(babelNodeText, 'node');
      outputPackageJson.scripts.dev = outputPackageJson.scripts.dev.replace(basisText, appName).replace(babelNodeText, 'node');
      outputPackageJson.scripts.prod = outputPackageJson.scripts.prod.replace(basisText, appName);
      outputPackageJson.scripts.test = outputPackageJson.scripts.test.replace(packageSpecsText, '');
      outputPackageJson.scripts.coverage = outputPackageJson.scripts.coverage.replace(packageSpecsText, '');

      _jsonfile2.default.writeFile(packageFilePath, outputPackageJson, { spaces: 2 }, function (writeError) {

        if (writeError) {
          reject(writeError);
        }

        resolve(answers);
      });
    });
  });
};

var cleanConfig = function cleanConfig(answers) {

  var replaceOptions = {

    files: answers.targetPath + '/config/settings.default.js',
    from: /basis/g,
    to: answers.appName
  };

  return new Promise(function (resolve, reject) {

    (0, _replaceInFile2.default)(replaceOptions).then(function (changedFiles) {
      resolve(answers);
    }).catch(function (error) {
      reject(error);
    });
  });
};

var notify = function notify(answers) {
  return new Promise(function (resolve, reject) {

    (0, _messages.status)('Initialised');
    resolve(answers);
  });
};

exports.default = function (answers) {
  return cleanFiles(answers).then(tweakPackageJson).then(cleanConfig).then(notify);
};